@@ -108,9 +108,10 @@ python modules. Normal usage is as in::
     INFO  [ordf.load/3148] Loading http://ordf.org/lens/rdfs
     INFO  [ordf.changeset] 612 changes urn:uuid:171ffd8c-8d12-11df-850a-001f5bef60ee
 
-In addition to the *-c* for specifying the config file and *-l* and *-v*
-for log file and debugging as with  :program:`ordf`, :program:`ordf_load`
-supports these arguments:
+In addition to the *-c* for specifying the config file, *-l* and *-v*
+for log file and debugging, and *-r* and *-w* for specifying readers and
+writers as with :program:`ordf`, :program:`ordf_load` supports these
+arguments:
 
 .. cmdoption:: -p, --package
 
@@ -125,7 +126,7 @@ Command Implementation -- :class:`Command`
 """
 from ordf.graph import Graph
 from ordf.handler import init_handler
-from ordf.namespace import RDF
+from ordf.namespace import RDF, RDFS
 from ordf.term import Literal, URIRef
 from ordf.vocab.opmv import Agent, Process
 from optparse import OptionParser
@@ -404,7 +405,7 @@ class ORDF(Command):
                 return exit_code
             self.log.info('-'*20 + ' Restarting ' + '-'*20)
 
-class LoadN3(Command):
+class ORDF_LOAD(Command):
     usage = "%prog [options]"
     parser = Command.StandardParser(usage=usage)
     parser.add_option("-p", "--package",
@@ -417,8 +418,24 @@ class LoadN3(Command):
                       action="store_true",
                       default=False,
                       help="Put data directly into store without changeset")
+    parser.add_option("-r", "--readers",
+                       dest="readers", default=None,
+                       help="comma separated list of reader plugins")
+    parser.add_option("-w", "--writers",
+                       dest="writers", default=None,
+                       help="comma separated list of writer plugins")
+
+    def parse_config(self):
+        super(ORDF_LOAD, self).parse_config()
+
+        ## override config with the command line
+        if self.options.readers:
+            self.config["ordf.readers"] = self.options.readers
+        if self.options.writers:
+            self.config["ordf.writers"] = self.options.writers
+
     def setup_logging(self):
-        super(LoadN3, self).setup_logging()
+        super(ORDF_LOAD, self).setup_logging()
         self.log = logging.getLogger("ordf.load/%s" % os.getpid())
 
     def command(self):
@@ -428,7 +445,11 @@ class LoadN3(Command):
 
         if hasattr(pkg, "rdf_data"):
             for graph in pkg.rdf_data():
-                self.log.info("Loading %s" % graph.identifier)
+                label = graph.one((graph.identifier, RDFS["label"], None))
+                if label is not None:
+                    self.log.info("Loading %s (%s)" % (graph.identifier, label[2]))
+                else:
+                    self.log.info("Loading %s" % (graph.identifier,))
                 if self.options.nocs:
                     self.handler.put(graph)
                 else:
@@ -441,4 +462,4 @@ def ordf():
     ORDF().command()
 
 def load_rdf():
-    LoadN3().command()
+    ORDF_LOAD().command()
