@@ -75,6 +75,12 @@ class RDFLib(HandlerPlugin):
         if hasattr(self.store, "sync"):
             self.store.sync()
 
+    def append(self, g):
+        old = Graph(self.store, identifier=g.identifier)
+        old += g
+        if hasattr(self.store, "sync"):
+            self.store.sync()
+                                    
     def remove(self, g):
         del self[g]
 
@@ -109,10 +115,14 @@ class FourStore(RDFLib):
         assert isinstance(g, _Graph)
         ident = get_identifier(k)
         cursor = self.store.cursor()
-        cursor.add_graph(g)
+        cursor.add_graph(g, replace=True)
     def __delitem__(self, k):
         ident = get_identifier(k)
         cursor = self.store.cursor()
         cursor.delete_graph(ident)
+    def append(self, frag):
+        ident = get_identifier(frag)
+        cursor = self.store.cursor()
+        cursor.add_graph(frag, replace=False)
     def query(self, *av, **kw):
         return self.store.query(*av, **kw)
