@@ -204,9 +204,11 @@ class predicate(property):
         if not isinstance(value, list) and not isinstance(value, tuple):
             value = (value,)
         for x in value:
-            if not isinstance(x, Node) and not isinstance(x, Individual):
+            if hasattr(x, "identifier") and isinstance(x.identifier, Node):
+                x = x.identifier
+            elif not isinstance(x, Node):
                 x = Literal(x)
-            obj.graph.add((obj.identifier, self.term, classOrTerm(x)))
+            obj.graph.add((obj.identifier, self.term, x))
     def _del(self, obj):
         obj.graph.remove((obj.identifier, self.term, None))
 
@@ -529,8 +531,10 @@ class Individual(object):
     .. automethod:: replace
     .. automethod:: serialize
     """
-    def __init__(self, identifier=None, graph=None):
+    def __init__(self, identifier=None, graph=None, factoryGraph=None):
         self.__identifier = identifier is not None and identifier or BNode()
+        if factoryGraph is not None:
+            self.factoryGraph = factoryGraph
         if graph is None:
             self.graph = self.factoryGraph
         else:
@@ -606,6 +610,10 @@ class Individual(object):
                 self.qname = u':'.join([prefix,localName])
             except:
                 pass
+
+    def __eq__(self, other):
+        assert isinstance(other,Individual), repr(other)
+        return self.identifier == other.identifier
             
     identifier = property(_get_identifier, _set_identifier)
     type = predicate(RDF.type)
@@ -633,8 +641,8 @@ class AnnotatibleTerms(Individual):
 
         Similarly for *rdfs:seeAlso*
     """
-    def __init__(self,identifier,graph=None):
-        super(AnnotatibleTerms, self).__init__(identifier,graph)
+    def __init__(self, identifier, graph=None, factoryGraph=None):
+        super(AnnotatibleTerms, self).__init__(identifier, graph=graph, factoryGraph=factoryGraph)
 
     label = predicate(RDFS.label)
     comment = predicate(RDFS.comment)
@@ -654,7 +662,7 @@ class Ontology(AnnotatibleTerms):
 
         Ditto with *owl:imports*
     """
-    def __init__(self, identifier=None,imports=None,comment=None,graph=None):
+    def __init__(self, identifier=None, imports=None, comment=None,graph=None):
         super(Ontology, self).__init__(identifier,graph)
         self.imports = imports and imports or []
         self.comment = comment and comment or []
@@ -834,7 +842,11 @@ class Class(AnnotatibleTerms):
     
         "..An owl:complementOf property links a class to precisely one class 
         description."
-      
+
+    .. automethod:: get
+    .. automethod:: get_or_create
+    .. automethod:: query
+    .. automethod:: filter
     """
     def _serialize(self,graph):
         for cl in self.subClassOf:
@@ -851,14 +863,15 @@ class Class(AnnotatibleTerms):
             graph.add(fact)
         self._serialize(graph)
     
-    def __init__(self, identifier=None,subClassOf=None,equivalentClass=None,
-                       disjointWith=None,complementOf=None,graph=None,
-                       skipOWLClassMembership = False,comment=None):
-        super(Class, self).__init__(identifier,graph)
+    def __init__(self, identifier=None, graph=None, factoryGraph=None, factoryClass=Individual,
+                 subClassOf=None,equivalentClass=None,
+                 disjointWith=None,complementOf=None,
+                 skipOWLClassMembership=False,comment=None):
+        super(Class, self).__init__(identifier, graph=graph, factoryGraph=factoryGraph)
         if not skipOWLClassMembership and (self.identifier,RDF.type,OWL.Class) not in self.graph and \
            (self.identifier,RDF.type,OWL.Restriction) not in self.graph:
             self.graph.add((self.identifier,RDF.type,OWL.Class))
-        
+        self.factoryClass    = factoryClass
         self.subClassOf      = subClassOf and subClassOf or [] 
         self.equivalentClass = equivalentClass and equivalentClass or []
         self.disjointWith    = disjointWith  and disjointWith or []
@@ -875,26 +888,80 @@ class Class(AnnotatibleTerms):
             return
         for m in other:
             self.graph.add((classOrIdentifier(m),RDF.type,self.identifier))
-            
     @TermDeletionHelper(RDF.type)
     def _del_type(self):            
         pass            
-            
     extent = property(_get_extent, _set_extent, _del_type)            
 
-    def _get_annotation(self,term=RDFS.label):
-        for annotation in self.graph.objects(subject=self,predicate=term):
-            yield annotation
-            
-    annotation = property(_get_annotation,lambda x:x)            
-
     def _get_extentQuery(self):
         return (Variable('CLASS'),RDF.type,self.identifier)
-
     def _set_extentQuery(self,other): pass
-            
     extentQuery = property(_get_extentQuery, _set_extentQuery)            
-    
+
+    def get(self, identifier):
+        """
+        Simple and naive individual retrieval from the factory graph.
+        Raises a KeyError if no individual with type of the present
+        class is found in the factory graph.
+
+        >>> EX=Namespace("http://example.org/")
+        >>> class Country(AnnotatibleTerms):
+        ...     def __init__(self, *av, **kw):
+        ...         super(Country, self).__init__(*av, **kw)
+        ...         self.type = EX.Country
+        ...
+        >>> class CountryClass(Class):
+        ...     def __init__(self, **kw):
+        ...         super(CountryClass, self).__init__(EX.Country, factoryClass=Country)
+        ...
+        >>> country = CountryClass()
+        >>> kenya = Country(EX.kenya)
+        >>> kenya.label = "Kenya"
+        >>> [str(x) for x in country.get(EX.kenya).label]
+        ['Kenya']
+        >>> country.get(EX.uganda)
+        Traceback (most recent call last):
+          raise KeyError("no individual %s with type %s" % (identifier, self.identifier))
+        KeyError: u'no individual http://example.org/uganda with type http://example.org/Country'
+        """
+        if self.factoryGraph.exists((identifier, RDF.type, self.identifier)):
+            return self.factoryClass(identifier, graph=self.factoryGraph)
+        raise KeyError("no individual %s with type %s" % (identifier, self.identifier))
+
+    def get_or_create(self, identifier):
+        """
+        Similar to the :meth:`get` except that it will not raise a key error
+        and will create the individual requested.
+        """
+        return self.factoryClass(identifier, graph=self.factoryGraph)
+
+    def query(self, *where):
+        """
+        Return a Telescope Select object that will query for individuals
+        with the RDF type of the present class and additional where
+        statements as provided.
+
+        >>> from telescope import v
+        >>> c = Class(URIRef("http://example.org/"))
+        >>> print c.query((v.id, RDFS.label, Literal("Russia"))).compile()
+        SELECT DISTINCT ?id
+        WHERE { ?id <http://www.w3.org/1999/02/22-rdf-syntax-ns#type> <http://example.org/> . ?id <http://www.w3.org/2000/01/rdf-schema#label> "Russia" }
+        """
+        from telescope import Select, v
+        q = Select([v.id], distinct=True).where(
+            (v.id, RDF.type, self.identifier)
+            ).where(*where)
+        return q
+
+    def filter(self, *where):
+        """
+        Return individuals that match the given query. The query will
+        be constructed via :meth:`query`
+        """
+        q = self.query(*where)
+        for identifier in self.factoryGraph.query(q.compile()):
+            yield self.factoryClass(identifier, graph=self.factoryGraph)
+            
     def __hash__(self):
         """
         >>> b=Class(OWL.Restriction)
